# API Index

.. contents::
   :local:

## Polygon annotations

.. autoclass:: ipyannotations.PolygonAnnotator

   .. rubric:: Methods
   .. automethod:: display
   .. automethod:: on_submit
   .. automethod:: on_skip
   .. automethod:: on_undo

   .. rubric:: Attributes
   .. autoattribute:: options
   .. autoattribute:: data

## Point annotations

.. autoclass:: ipyannotations.PointAnnotator

   .. rubric:: Methods
   .. automethod:: display
   .. automethod:: on_submit
   .. automethod:: on_skip
   .. automethod:: on_undo

   .. rubric:: Attributes
   .. autoattribute:: options
   .. autoattribute:: data

## Bounding box annotations

.. autoclass:: ipyannotations.BoxAnnotator

   .. rubric:: Methods
   .. automethod:: display
   .. automethod:: on_submit
   .. automethod:: on_skip
   .. automethod:: on_undo

   .. rubric:: Attributes
   .. autoattribute:: options
   .. autoattribute:: data
